@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -59,8 +59,8 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int FIGHTER_MOVE_X[2][NB_DIRS][5];
-int FIGHTER_MOVE_Y[2][NB_DIRS][5];
+extern int FIGHTER_MOVE_X[2][NB_DIRS][5];
+extern int FIGHTER_MOVE_Y[2][NB_DIRS][5];
 
 /*==================================================================*/
 /* fonctions globales                                               */
