@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -54,12 +54,12 @@
 
 #include <allegro.h>
 #include <stdlib.h>
-#include <time.h>
 #ifdef DOS
 #include <dos.h>
 #endif
 
 #include "base.h"
+#include "initrand.h"
 #include "config.h"
 #include "gfxmode.h"
 #include "init.h"
@@ -117,10 +117,9 @@ init_all ()
     mouse = 1, sound = 1, joystick = 1, network = 1;
 
   /*
-   * we use srand to garantee that random() won't return the same values
-   * each time the game is run
+   * Initialize random number generator with current time
    */
-  srandom (time (NULL));
+  lw_random_init ();
 
   set_startup ();
   log_init ();
