@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -239,6 +239,10 @@ internet_find (void)
         }
     }
 
+  /* Clear static pointers to avoid dangling references */
+  list_data = NULL;
+  list_size = NULL;
+
   if (retour > 0)
     retour--;
 
