@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -53,9 +53,11 @@
 
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <allegro.h>
 
 #include "random.h"
+#include "base.h"
 #include "alleg2.h"
 #include "map.h"
 #include "config.h"
