@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -66,8 +66,8 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-void *LW_RANDOM_RAW_MAP;
-int LW_RANDOM_ON;
+extern void *LW_RANDOM_RAW_MAP;
+extern int LW_RANDOM_ON;
 
 /*==================================================================*/
 /* fonctions globales                                               */
