@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -520,7 +520,8 @@ lw_srvcont_wait_teams (LW_SRVCONT * cont,
     {
       log_print_str ("Unable to bind socket on port ");
       log_print_int (port);
-      log_println ("!");
+      log_print_str ("!");
+      log_println ();
 
       /*
        * We consider this a fatal error and quit the program
