@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2018 Christian Mauduit                                 */
+/* Copyright (C) 1998-2025 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -430,7 +430,7 @@ main (int argc, char **argv)
             {
               if (FLAG_BACKUP)
                 save_backup (FILENAMES[i]);
-              convert_bitmap (FILENAMES[i]);
+              convert_bitmap ();
               save_file (FILENAMES[i]);
             }
         }
